@@ -1,5 +1,5 @@
 
-# $Id: Motors.pm,v 1.11 2008/04/27 13:52:57 Martin Exp $
+# $Id: Motors.pm,v 1.12 2008/09/07 00:27:41 Martin Exp $
 
 =head1 NAME
 
@@ -65,7 +65,7 @@ use Carp;
 use Data::Dumper;
 use base 'WWW::Search::Ebay';
 our
-$VERSION = do { my @r = (q$Revision: 1.11 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.12 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 our $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 
 sub _native_setup_search
@@ -81,31 +81,10 @@ sub _native_setup_search
   return $self->SUPER::_native_setup_search($native_query, $rhOptsArg);
   } # _native_setup_search
 
-sub _result_count_element_specs
-  {
-  return (
-          '_tag' => 'div',
-          id => 'matchesFound'
-         );
-  } # _result_count_element_specs
-
-sub _result_count_pattern
-  {
-  return qr'(\d+)\s+match(es)?\s+found';
-  } # _result_count_pattern
-
-sub _title_element_specs
-  {
-  return (
-          '_tag' => 'td',
-          'class' => 'details',
-         );
-  } # _title_element_specs
-
 sub _columns
   {
   my $self = shift;
-  return qw( bids price enddate paypal );
+  return qw( bids price enddate );
   } # _columns
 
 1;
